import org.faceless.pdf2.*;
import java.io.*;
import java.util.*;

/**
 * Demonstrates creating a PDF Portfolio, for use with Acrobat 9 or later.
 */
public class Portfolio {

    public static void main(String[] args) throws IOException {
        PDF pdf = new PDF();
        pdf.makePortfolio(true);
        Map<String,EmbeddedFile> files = pdf.getEmbeddedFiles();

        for (int i=0;i<args.length;i++) {
            File f = new File(args[i]);
            System.out.println("Adding \""+f.getName()+"\"");
            EmbeddedFile ef = new EmbeddedFile(f);
            if (args[i].toLowerCase().endsWith(".pdf")) {
                ef.setType("application/pdf");
            }
            // If you wanted to place the file in a subfolder in the PDF,
            // this is how you would do it. Acrobat 9 will ignore the folders,
            // but Acrobat X and later will honour them.
            // ef.setPortfolioFolder("path/to/subfolder");

            files.put(f.getName(), ef);
        }

        // You have to have at least one page in a PDF, although it will only
        // be visible to PDF viewers that don't support portfolios. Blank is OK.
        PDFPage page = pdf.newPage("A4");

        // Next line is not really required but helpful if you're targetting Acrobat 8.
        pdf.setOption("pagemode", "UseAttachments");

        pdf.render(new FileOutputStream("Portfolio.pdf"));
    }

}
